# Overview
As of 2025-09-22, the XML schema files necessary to fully validate a SIDD XML are not available on the NSG
standards registry. This README describes the provenance of the SIDD schemas that SARkit uses.

## `version1`
The files in this folder were copied from:
https://github.com/ngageoint/six-library/tree/448e6d659bb4b650fcc19e4b909353203c3a5195/six/modules/c%2B%2B/six.sidd/conf/schema

which are largely similar to those in:
https://github.com/ngageoint/sarpy/tree/abbd570dbb6c8ccfde91b22def8b0365b45856da/sarpy/io/product/sidd_schema/version1

with exceptions being apparent fixes in `SFA.xsd` and `SICommonTypes.xsd`.

## `version2`
This files in this folder were copied from:
https://github.com/ngageoint/sarpy/tree/bb17d79315ca5fead3da4db11013fd1430ed0f6a/sarpy/io/product/sidd_schema/version2

## `version3`
This files in this folder were copied from:
https://github.com/ngageoint/sarpy/tree/bb17d79315ca5fead3da4db11013fd1430ed0f6a/sarpy/io/product/sidd_schema/version3
